@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2015-2019 Satpy developers
+# Copyright (c) 2015-2020 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -55,6 +55,10 @@ LOG = logging.getLogger(__name__)
 NEGLIBLE_COORDS = ['time']
 """Keywords identifying non-dimensional coordinates to be ignored during composite generation."""
 
+MASKING_COMPOSITOR_METHODS = ['less', 'less_equal', 'equal', 'greater_equal',
+                              'greater', 'not_equal', 'isnan', 'isfinite',
+                              'isneginf', 'isposinf']
+
 
 class IncompatibleAreas(Exception):
     """Error raised upon compositing things of different shapes."""
@@ -589,6 +593,19 @@ class PSPRayleighReflectance(CompositeBase):
 class NIRReflectance(CompositeBase):
     """Get the reflective part of NIR bands."""
 
+    def __init__(self, sunz_threshold=None, **kwargs):
+        """Collect custom configuration values.
+
+        Args:
+            sunz_threshold: The threshold sun zenith angle used when deriving
+                the near infrared reflectance. Above this angle the derivation
+                will assume this sun-zenith everywhere. Default None, in which
+                case the default threshold defined in Pyspectral will be used.
+
+        """
+        self.sunz_threshold = sunz_threshold
+        super(NIRReflectance, self).__init__(sunz_threshold=sunz_threshold, **kwargs)
+
     def __call__(self, projectables, optional_datasets=None, **info):
         """Get the reflectance part of an NIR channel.
 
@@ -604,8 +621,8 @@ class NIRReflectance(CompositeBase):
                             coords=_nir.coords, attrs=_nir.attrs)
 
         proj.attrs['units'] = '%'
+        proj.attrs['sunz_threshold'] = self.sunz_threshold
         self.apply_modifier_info(_nir, proj)
-
         return proj
 
     def _init_refl3x(self, projectables):
@@ -614,7 +631,8 @@ class NIRReflectance(CompositeBase):
             LOG.info("Couldn't load pyspectral")
             raise ImportError("No module named pyspectral.near_infrared_reflectance")
         _nir, _tb11 = projectables
-        self._refl3x = Calculator(_nir.attrs['platform_name'], _nir.attrs['sensor'], _nir.attrs['name'])
+        self._refl3x = Calculator(_nir.attrs['platform_name'], _nir.attrs['sensor'], _nir.attrs['name'],
+                                  sunz_threshold=self.sunz_threshold)
 
     def _get_reflectance(self, projectables, optional_datasets):
         """Calculate 3.x reflectance with pyspectral."""
@@ -645,7 +663,19 @@ class NIRReflectance(CompositeBase):
 
 
 class NIREmissivePartFromReflectance(NIRReflectance):
-    """Get the emissive par of NIR bands."""
+    """Get the emissive part of NIR bands."""
+
+    def __init__(self, sunz_threshold=None, **kwargs):
+        """Collect custom configuration values.
+
+        Args:
+            sunz_threshold: The threshold sun zenith angle used when deriving
+                the near infrared reflectance. Above this angle the derivation
+                will assume this sun-zenith everywhere. Default None, in which
+                case the default threshold defined in Pyspectral will be used.
+        """
+        self.sunz_threshold = sunz_threshold
+        super(NIREmissivePartFromReflectance, self).__init__(sunz_threshold=sunz_threshold, **kwargs)
 
     def __call__(self, projectables, optional_datasets=None, **info):
         """Get the emissive part an NIR channel after having derived the reflectance.
@@ -661,12 +691,13 @@ class NIREmissivePartFromReflectance(NIRReflectance):
         # needs to be derived first in order to get the emissive part.
         _ = self._get_reflectance(projectables, optional_datasets)
         _nir, _ = projectables
-        proj = xr.DataArray(self._refl3x.emissive_part_3x(), attrs=_nir.attrs,
-                            dims=_nir.dims, coords=_nir.coords)
+
+        emis = self._refl3x.emissive_part_3x()
+        proj = xr.DataArray(emis, attrs=_nir.attrs, dims=_nir.dims, coords=_nir.coords)
 
         proj.attrs['units'] = 'K'
+        proj.attrs['sunz_threshold'] = self.sunz_threshold
         self.apply_modifier_info(_nir, proj)
-
         return proj
 
 
@@ -1596,30 +1627,40 @@ class BackgroundCompositor(GenericCompositor):
 class MaskingCompositor(GenericCompositor):
     """A compositor that masks e.g. IR 10.8 channel data using cloud products from NWC SAF."""
 
-    def __init__(self, name, transparency=None, **kwargs):
+    def __init__(self, name, transparency=None, conditions=None, **kwargs):
         """Collect custom configuration values.
 
-        Args:
-            transparency: transparency for each cloud type as key-value pairs
-                          in a dictionary
+        Kwargs:
+            transparency (dict): transparency for each cloud type as
+                                 key-value pairs in a dictionary.
+                                 Will be converted to `conditions`.
+                                 DEPRECATED.
+            conditions (list): list of three items determining the masking
+                               settings.
 
-        The `transparencies` can be either the numerical values in the
-        data used as a mask with the corresponding transparency
-        (0...100 %) as the value, or, for NWC SAF products, the flag
-        names in the dataset `flag_meanings` attribute.
-
-        Transparency value of `0` means that the composite being
-        masked will be fully visible, and `100` means it will be
-        completely transparent and not visible in the resulting image.
-
-        For the mask values not listed in `transparencies`, the data will
-        be completely opaque (transparency = 0).
+        Each condition in *conditions* consists of of three items:
+        - `method`: Numpy method name.  The following are supported
+           operations: `less`, `less_equal`, `equal`, `greater_equal`,
+           `greater`, `not_equal`, `isnan`, `isfinite`, `isinf`,
+          `isneginf`, `isposinf`
+        - `value`: threshold value of the *mask* applied with the
+          operator.  Can be a string, in which case the corresponding
+          value will be determined from `flag_meanings` and
+          `flag_values` attributes of the mask.
+          NOTE: the `value` should not be given to 'is*` methods.
+        - `transparency`: transparency from interval [0 ... 100] used
+          for the method/threshold. Value of 100 is fully transparent.
 
         Example::
 
-          >>> transparency = {0: 100,
-                              1: 80,
-                              2: 0}
+          >>> conditions = [{'method': 'greater_equal', 'value': 0,
+                             'transparency': 100},
+                            {'method': 'greater_equal', 'value': 1,
+                             'transparency': 80},
+                            {'method': 'greater_equal', 'value': 2,
+                             'transparency': 0},
+                            {'method': 'isnan',
+                             'transparency': 100}]
           >>> compositor = MaskingCompositor("masking compositor",
                                              transparency=transparency)
           >>> result = compositor([data, mask])
@@ -1628,17 +1669,30 @@ class MaskingCompositor(GenericCompositor):
         the `mask` dataset.  Locations where `mask` has values of `0`
         will be fully transparent, locations with `1` will be
         semi-transparent and locations with `2` will be fully visible
-        in the resulting image.  All the unlisted locations will be
+        in the resulting image.  In the end all `NaN` areas in the mask are
+        set to full transparency.  All the unlisted locations will be
         visible.
 
         The transparency is implemented by adding an alpha layer to
-        the composite.  If the input `data` contains an alpha channel,
-        it will be discarded.
+        the composite.  The locations with transparency of `100` will
+        be set to NaN in the data.  If the input `data` contains an
+        alpha channel, it will be discarded.
 
         """
-        if transparency is None:
-            raise ValueError("No transparency configured for simple masking compositor")
-        self.transparency = transparency
+        if transparency:
+            LOG.warning("Using 'transparency' is deprecated in "
+                        "MaskingCompositor, use 'conditions' instead.")
+            self.conditions = []
+            for key, transp in transparency.items():
+                self.conditions.append({'method': 'equal',
+                                        'value': key,
+                                        'transparency': transp})
+            LOG.info("Converted 'transparency' to 'conditions': %s",
+                     str(self.conditions))
+        else:
+            self.conditions = conditions
+        if self.conditions is None:
+            raise ValueError("Masking conditions not defined.")
 
         super(MaskingCompositor, self).__init__(name, **kwargs)
 
@@ -1647,35 +1701,82 @@ class MaskingCompositor(GenericCompositor):
         if len(projectables) != 2:
             raise ValueError("Expected 2 datasets, got %d" % (len(projectables),))
         projectables = self.match_data_arrays(projectables)
-        cloud_mask = projectables[1]
-        cloud_mask_data = cloud_mask.data
-        data = projectables[0]
-        alpha_attrs = data.attrs.copy()
-        if 'bands' in data.dims:
-            data = [data.sel(bands=b) for b in data['bands'] if b != 'A']
+        data_in = projectables[0]
+        mask_in = projectables[1]
+        mask_data = mask_in.data
+
+        alpha_attrs = data_in.attrs.copy()
+        if 'bands' in data_in.dims:
+            data = [data_in.sel(bands=b) for b in data_in['bands'] if b != 'A']
         else:
-            data = [data]
+            data = [data_in]
 
         # Create alpha band
         alpha = da.ones((data[0].sizes['y'],
                          data[0].sizes['x']),
                         chunks=data[0].chunks)
 
-        # Modify alpha based on transparency per class from yaml
-        flag_meanings = cloud_mask.attrs['flag_meanings']
-        flag_values = cloud_mask.attrs['flag_values']
+        for condition in self.conditions:
+            method = condition['method']
+            value = condition.get('value', None)
+            if isinstance(value, str):
+                value = _get_flag_value(mask_in, value)
+            transparency = condition['transparency']
+            mask = self._get_mask(method, value, mask_data)
 
-        if isinstance(flag_meanings, str):
-            flag_meanings = flag_meanings.split()
+            if transparency == 100.0:
+                data = self._set_data_nans(data, mask, alpha_attrs)
+            alpha_val = 1. - transparency / 100.
+            alpha = da.where(mask, alpha_val, alpha)
 
-        for key, val in self.transparency.items():
-            if isinstance(key, str):
-                key_index = flag_meanings.index(key)
-                key = flag_values[key_index]
-            alpha_val = 1. - val / 100.
-            alpha = da.where(cloud_mask_data == key, alpha_val, alpha)
         alpha = xr.DataArray(data=alpha, attrs=alpha_attrs,
                              dims=data[0].dims, coords=data[0].coords)
         data.append(alpha)
+
         res = super(MaskingCompositor, self).__call__(data, **kwargs)
         return res
+
+    def _get_mask(self, method, value, mask_data):
+        """Get mask array from *mask_data* using *method* and threshold *value*.
+
+        The *method* is the name of a numpy function.
+
+        """
+        if method not in MASKING_COMPOSITOR_METHODS:
+            raise AttributeError("Unsupported Numpy method %s, use one of %s",
+                                 method, str(MASKING_COMPOSITOR_METHODS))
+
+        func = getattr(np, method)
+
+        if value is None:
+            return func(mask_data)
+        return func(mask_data, value)
+
+    def _set_data_nans(self, data, mask, attrs):
+        """Set *data* to nans where *mask* is True.
+
+        The attributes *attrs** will be written to each band in *data*.
+
+        """
+        for i, dat in enumerate(data):
+            data[i] = xr.where(mask, np.nan, dat)
+            data[i].attrs = attrs
+
+        return data
+
+
+def _get_flag_value(mask, val):
+    """Get a numerical value of the named flag.
+
+    This function assumes the naming used in product generated with
+    NWC SAF GEO/PPS softwares.
+
+    """
+    flag_meanings = mask.attrs['flag_meanings']
+    flag_values = mask.attrs['flag_values']
+    if isinstance(flag_meanings, str):
+        flag_meanings = flag_meanings.split()
+
+    index = flag_meanings.index(val)
+
+    return flag_values[index]
