@@ -162,7 +162,7 @@ class ModisL2HDFFileHandler(HDFEOSGeoReader):
 
         # No byte manipulation required
         else:
-            dataset = self.load_dataset(dataset_name)
+            dataset = self.load_dataset(dataset_name_in_file)
 
         return dataset
 
