@@ -42,11 +42,6 @@ from satpy.readers.utils import np2str
 from satpy.utils import angle2xyz, lonlat2xyz, xyz2angle, xyz2lonlat
 from satpy import CHUNK_SIZE
 
-try:
-    import tables
-except ImportError:
-    tables = None
-
 chans_dict = {"M01": "M1",
               "M02": "M2",
               "M03": "M3",
@@ -147,6 +142,13 @@ class VIIRSCompactFileHandler(BaseFileHandler):
         self.mda['platform_name'] = short_names.get(short_name, short_name)
         self.mda['sensor'] = 'viirs'
 
+    def __del__(self):
+        """Close file handlers when we are done."""
+        try:
+            self.h5f.close()
+        except OSError:
+            pass
+
     def get_dataset(self, key, info):
         """Load a dataset."""
         logger.debug('Reading %s.', key.name)
@@ -155,6 +157,7 @@ class VIIRSCompactFileHandler(BaseFileHandler):
         else:
             m_data = self.read_geo(key, info)
         m_data.attrs.update(info)
+        m_data.attrs['rows_per_scan'] = self.scan_size
         return m_data
 
     def get_bounding_box(self):
