@@ -178,6 +178,21 @@ class TestGRIBReader(unittest.TestCase):
         # make sure we have some files
         self.assertTrue(r.file_handlers)
 
+    def test_file_pattern(self):
+        """Test matching of file patterns."""
+        from satpy.readers import load_reader
+
+        filenames = [
+                "quinoa.grb",
+                "tempeh.grb2",
+                "tofu.grib2",
+                "falafel.grib",
+                "S_NWC_NWP_1900-01-01T00:00:00Z_999.grib"]
+
+        r = load_reader(self.reader_configs)
+        files = r.select_files_from_pathnames(filenames)
+        self.assertEqual(len(files), 4)
+
     @mock.patch('satpy.readers.grib.pygrib')
     def test_load_all(self, pg):
         """Test loading all test datasets"""
