@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2017-2018 Satpy developers
+# Copyright (c) 2017-2020 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -54,6 +54,7 @@ class FakeNetCDF4FileHandler(NetCDF4FileHandler):
             - '/attr/global_attr'
             - 'dataset/attr/global_attr'
             - 'dataset/shape'
+            - 'dataset/dimensions'
             - '/dimension/my_dim'
 
         """
@@ -122,10 +123,15 @@ class TestNetCDF4FileHandler(unittest.TestCase):
         for ds in ('test_group/ds1_f', 'test_group/ds1_i', 'ds2_f', 'ds2_i'):
             self.assertEqual(file_handler[ds].dtype, np.float32 if ds.endswith('f') else np.int32)
             self.assertTupleEqual(file_handler[ds + '/shape'], (10, 100))
+            self.assertEqual(file_handler[ds + '/dimensions'], ("rows", "cols"))
             self.assertEqual(file_handler[ds + '/attr/test_attr_str'], 'test_string')
             self.assertEqual(file_handler[ds + '/attr/test_attr_int'], 0)
             self.assertEqual(file_handler[ds + '/attr/test_attr_float'], 1.2)
 
+        test_group = file_handler['test_group']
+        self.assertTupleEqual(test_group['ds1_i'].shape, (10, 100))
+        self.assertTupleEqual(test_group['ds1_i'].dims, ('rows', 'cols'))
+
         self.assertEqual(file_handler['/attr/test_attr_str'], 'test_string')
         self.assertEqual(file_handler['/attr/test_attr_str_arr'], 'test_string2')
         self.assertEqual(file_handler['/attr/test_attr_int'], 0)
@@ -141,8 +147,7 @@ class TestNetCDF4FileHandler(unittest.TestCase):
         self.assertEqual(file_handler["ds2_sc"], 42)
 
     def test_caching(self):
-        """Test that caching works as intended.
-        """
+        """Test that caching works as intended."""
         from satpy.readers.netcdf_utils import NetCDF4FileHandler
         h = NetCDF4FileHandler("test.nc", {}, {}, cache_var_size=1000,
                                cache_handle=True)
@@ -155,12 +160,16 @@ class TestNetCDF4FileHandler(unittest.TestCase):
         np.testing.assert_array_equal(h["ds2_s"], np.arange(10))
         np.testing.assert_array_equal(h["test_group/ds1_i"],
                                       np.arange(10 * 100).reshape((10, 100)))
+        # check that root variables can still be read from cached file object,
+        # even if not cached themselves
+        np.testing.assert_array_equal(
+                h["ds2_f"],
+                np.arange(10. * 100).reshape((10, 100)))
         h.__del__()
         self.assertFalse(h.file_handle.isopen())
 
     def test_filenotfound(self):
-        """Test that error is raised when file not found
-        """
+        """Test that error is raised when file not found."""
         from satpy.readers.netcdf_utils import NetCDF4FileHandler
 
         with self.assertRaises(IOError):
