@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (c) 2018 Satpy developers
+# Copyright (c) 2018, 2020 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -17,11 +17,7 @@
 """Unittests for NWC SAF reader."""
 
 import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
 
 PROJ_KM = {'gdal_projection': '+proj=geos +a=6378.137000 +b=6356.752300 +lon_0=0.000000 +h=35785.863000',
            'gdal_xgeo_up_left': -5569500.0,
@@ -47,6 +43,36 @@ class TestNcNWCSAF(unittest.TestCase):
         unzip.return_value = ''
         self.scn = NcNWCSAF('filename', {}, {})
 
+    def test_sensor_name(self):
+        """Test that the correct sensor name is being set"""
+
+        self.scn.set_platform_and_sensor(platform_name='Metop-B')
+        self.assertTrue(self.scn.sensor, set(['avhrr-3']))
+        self.assertTrue(self.scn.sensor_names, set(['avhrr-3']))
+
+        self.scn.set_platform_and_sensor(platform_name='NOAA-20')
+        self.assertTrue(self.scn.sensor, set(['viirs']))
+        self.assertTrue(self.scn.sensor_names, set(['viirs']))
+
+        self.scn.set_platform_and_sensor(platform_name='Himawari-8')
+        self.assertTrue(self.scn.sensor, set(['ahi']))
+        self.assertTrue(self.scn.sensor_names, set(['ahi']))
+
+        self.scn.set_platform_and_sensor(sat_id='GOES16')
+        self.assertTrue(self.scn.sensor, set(['abi']))
+        self.assertTrue(self.scn.sensor_names, set(['abi']))
+
+        self.scn.set_platform_and_sensor(platform_name='GOES-17')
+        self.assertTrue(self.scn.sensor, set(['abi']))
+        self.assertTrue(self.scn.sensor_names, set(['abi']))
+
+        self.scn.set_platform_and_sensor(sat_id='MSG4')
+        self.assertTrue(self.scn.sensor, set(['seviri']))
+
+        self.scn.set_platform_and_sensor(platform_name='Meteosat-11')
+        self.assertTrue(self.scn.sensor, set(['seviri']))
+        self.assertTrue(self.scn.sensor_names, set(['seviri']))
+
     def test_get_projection(self):
         """Test generation of the navigation info."""
         # a, b and h in kilometers
@@ -124,15 +150,14 @@ class TestNcNWCSAF(unittest.TestCase):
         self.assertNotIn('scale_factor', var.attrs)
         self.assertNotIn('add_offset', var.attrs)
 
-
-def suite():
-    """Test suite for test_writers."""
-    loader = unittest.TestLoader()
-    my_suite = unittest.TestSuite()
-    my_suite.addTest(loader.loadTestsFromTestCase(TestNcNWCSAF))
-
-    return my_suite
-
-
-if __name__ == '__main__':
-    unittest.main()
+        # CTTH NWCSAF/Geo v2016/v2018:
+        attrs = {'scale_factor': np.array(1.),
+                 'add_offset': np.array(-2000.),
+                 'valid_range': (0., 27000.)}
+        var = xr.DataArray([1, 2, 3], attrs=attrs)
+        var = self.scn.scale_dataset('dummy', var, 'dummy')
+        np.testing.assert_allclose(var, [-1999., -1998., -1997.])
+        self.assertNotIn('scale_factor', var.attrs)
+        self.assertNotIn('add_offset', var.attrs)
+        self.assertEqual(var.attrs['valid_range'][0], -2000.)
+        self.assertEqual(var.attrs['valid_range'][1], 25000.)
