@@ -62,7 +62,7 @@ TEST_AREA_EXTENT_EARTHMODEL1_VISIR_FULLDISK = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 3712,
         'Number of rows': 3712,
-        'Area extent': (-5568748.2758, -5568748.2758, 5568748.2758, 5568748.2758)
+        'Area extent': (5568748.2758, 5568748.2758, -5568748.2758, -5568748.2758)
     }
 }
 
@@ -79,7 +79,7 @@ TEST_AREA_EXTENT_EARTHMODEL1_VISIR_ROI = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 2516,
         'Number of rows': 1829,
-        'Area extent': (-2205296.3269, -333044.7514, 5337717.232, 5154692.6389)
+        'Area extent': (5337717.232, 5154692.6389, -2205296.3269, -333044.7514)
     }
 }
 
@@ -96,8 +96,8 @@ TEST_AREA_EXTENT_EARTHMODEL1_HRV_FULLDISK = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 5568,
         'Number of rows': 11136,
-        'Area extent 0': (-1964263.8611793518, 2623352.397084236, 3604484.1933250427, 5567747.920155525),
-        'Area extent 1': (1000.1343488693237, -5569748.188853264, 5569748.188853264, 2623352.397084236)
+        'Area extent 0': (5567747.920155525, 2625352.665781975, -1000.1343488693237, -5567747.920155525),
+        'Area extent 1': (3602483.924627304, 5569748.188853264, -1966264.1298770905, 2625352.665781975)
     }
 }
 
@@ -114,7 +114,7 @@ TEST_AREA_EXTENT_EARTHMODEL1_HRV_ROI = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 11136,
         'Number of rows': 11136,
-        'Area extent': (-2204296.1049, -332044.6038, 5336716.8856, 5153692.2997)
+        'Area extent': (5334716.616868973, 5155692.568421364, -2206296.373605728, -330044.33512687683)
     }
 }
 
@@ -131,7 +131,7 @@ TEST_AREA_EXTENT_EARTHMODEL2_VISIR_FULLDISK = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 3712,
         'Number of rows': 3712,
-        'Area extent': (-5570248.4773, -5567248.0742, 5567248.0742, 5570248.4773)
+        'Area extent': (5567248.0742, 5570248.4773, -5570248.4773, -5567248.0742)
     }
 }
 
@@ -148,8 +148,8 @@ TEST_AREA_EXTENT_EARTHMODEL2_HRV_FULLDISK = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 5568,
         'Number of rows': 11136,
-        'Area extent 0': (-1965764.0627026558, 2624852.59860754, 3602983.9918017387, 5569248.121678829),
-        'Area extent 1': (-500.06717443466187, -5568247.98732996, 5568247.98732996, 2624852.59860754)
+        'Area extent 0': (5566247.718632221, 2626852.867305279, -2500.3358721733093, -5566247.718632221),
+        'Area extent 1': (3600983.723104, 5571248.390376568, -1967764.3314003944, 2626852.867305279)
     }
 }
 
@@ -166,7 +166,7 @@ TEST_AREA_EXTENT_EARTHMODEL2_VISIR_ROI = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 2516,
         'Number of rows': 1829,
-        'Area extent': (-2206796.5285, -331544.5498, 5336217.0304, 5156192.8405)
+        'Area extent': (5336217.0304, 5156192.8405, -2206796.5285, -331544.5498)
     }
 }
 
@@ -183,7 +183,7 @@ TEST_AREA_EXTENT_EARTHMODEL2_HRV_ROI = {
                        'type': 'crs', 'units': 'm', 'x_0': '0', 'y_0': '0'},
         'Number of columns': 11136,
         'Number of rows': 11136,
-        'Area extent': (-2205796.3064, -330544.4023, 5335216.684, 5155192.5012)
+        'Area extent': (5333216.415345669, 5157192.769944668, -2207796.575129032, -328544.13360357285)
     }
 }
 
