@@ -16,19 +16,11 @@
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Tests for the VIIRS EDR Flood reader."""
-import sys
 import os
+import unittest
+from unittest import mock
 import numpy as np
 from satpy.tests.reader_tests.test_hdf4_utils import FakeHDF4FileHandler
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
 
 
 DEFAULT_FILE_DTYPE = np.uint16
@@ -131,12 +123,3 @@ class TestVIIRSEDRFloodReader(unittest.TestCase):
         self.assertEqual(len(datasets), 1)
         for v in datasets.values():
             self.assertEqual(v.attrs['units'], 'none')
-
-
-def suite():
-    """Create the test suite for test_viirs_edr_flood."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestVIIRSEDRFloodReader))
-
-    return mysuite
