@@ -138,6 +138,80 @@ class TestMultiScene(unittest.TestCase):
             calls = [mock.call(filenames={'abi_l1b': [in_file]}) for in_file in input_files]
             scn_mock.assert_has_calls(calls)
 
+    def test_group(self):
+        from satpy import Scene, MultiScene, DatasetID
+
+        ds1 = _create_test_dataset(name='ds1')
+        ds2 = _create_test_dataset(name='ds2')
+        ds3 = _create_test_dataset(name='ds3')
+        ds4 = _create_test_dataset(name='ds4')
+        scene1 = Scene()
+        scene1['ds1'] = ds1
+        scene1['ds2'] = ds2
+        scene2 = Scene()
+        scene2['ds3'] = ds3
+        scene2['ds4'] = ds4
+
+        multi_scene = MultiScene([scene1, scene2])
+        groups = {DatasetID(name='odd', wavelength=(1, 2, 3)): ['ds1', 'ds3'],
+                  DatasetID(name='even', wavelength=(2, 3, 4)): ['ds2', 'ds4']}
+        multi_scene.group(groups)
+
+        self.assertSetEqual(multi_scene.shared_dataset_ids, set(groups.keys()))
+
+    def test_add_group_aliases(self):
+        """Test adding group aliases."""
+        import xarray as xr
+        import numpy as np
+        import types
+
+        from satpy.multiscene import add_group_aliases
+        from satpy import DatasetID
+        from satpy import Scene
+
+        # Define test scenes
+        ds_id1 = DatasetID('ds1', wavelength=(10.7, 10.8, 10.9))
+        ds_id2 = DatasetID('ds2', wavelength=(1.9, 2.0, 2.1))
+        ds_id3 = DatasetID('ds3', wavelength=(10.8, 10.9, 11.0))
+        ds_id31 = DatasetID('ds31', polarization='H')
+
+        scene1 = Scene()
+        scene1[ds_id1] = xr.DataArray([1])
+        scene2 = Scene()
+        scene2[ds_id2] = xr.DataArray([2])
+        scene3 = Scene()
+        scene3[ds_id3] = xr.DataArray([3])
+        scene3[ds_id31] = xr.DataArray([4])
+        scenes = [scene1, scene2, scene3]
+
+        # Define groups
+        g1 = DatasetID(name='g1', wavelength=(10, 11, 12))
+        g2 = DatasetID(name='g2', wavelength=(1, 2, 3), polarization='V')
+        groups = {g1: ['ds1', 'ds3'], g2: ['ds2']}
+
+        # Test adding aliases
+        with_aliases = add_group_aliases(iter(scenes), groups)
+        self.assertIsInstance(with_aliases, types.GeneratorType)
+        with_aliases = list(with_aliases)
+        self.assertSetEqual(set(with_aliases[0].keys()), {g1, ds_id1})
+        self.assertSetEqual(set(with_aliases[1].keys()), {g2, ds_id2})
+        self.assertSetEqual(set(with_aliases[2].keys()), {g1, ds_id3, ds_id31})
+
+        np.testing.assert_array_equal(with_aliases[0]['g1'].values, [1])
+        np.testing.assert_array_equal(with_aliases[0]['ds1'].values, [1])
+        np.testing.assert_array_equal(with_aliases[1]['g2'].values, [2])
+        np.testing.assert_array_equal(with_aliases[1]['ds2'].values, [2])
+        np.testing.assert_array_equal(with_aliases[2]['g1'].values, [3])
+        np.testing.assert_array_equal(with_aliases[2]['ds3'].values, [3])
+        np.testing.assert_array_equal(with_aliases[2]['ds31'].values, [4])
+
+        # Make sure that modifying the result doesn't modify the original
+        self.assertNotIn(g1, scene1)
+
+        # Adding an alias for multiple datasets in one scene should fail
+        gen = add_group_aliases([scene3], {g1: ['ds3', 'ds31']})
+        self.assertRaises(ValueError, list, gen)
+
 
 class TestMultiSceneSave(unittest.TestCase):
     """Test saving a MultiScene to various formats."""
@@ -434,6 +508,12 @@ class TestBlendFuncs(unittest.TestCase):
         ds2 = xr.DataArray(da.zeros((2, 2), chunks=-1), dims=('y', 'x'),
                            attrs={'start_time': datetime(2018, 1, 1, 1, 0, 0), 'area': area})
         self.ds2 = ds2
+        ds3 = xr.DataArray(da.zeros((2, 2), chunks=-1), dims=('y', 'time'),
+                           attrs={'start_time': datetime(2018, 1, 1, 0, 0, 0), 'area': area})
+        self.ds3 = ds3
+        ds4 = xr.DataArray(da.zeros((2, 2), chunks=-1), dims=('y', 'time'),
+                           attrs={'start_time': datetime(2018, 1, 1, 1, 0, 0), 'area': area})
+        self.ds4 = ds4
 
     def test_stack(self):
         """Test the 'stack' function."""
@@ -446,5 +526,8 @@ class TestBlendFuncs(unittest.TestCase):
         from satpy.multiscene import timeseries
         import xarray as xr
         res = timeseries([self.ds1, self.ds2])
+        res2 = timeseries([self.ds3, self.ds4])
         self.assertIsInstance(res, xr.DataArray)
+        self.assertIsInstance(res2, xr.DataArray)
         self.assertTupleEqual((2, self.ds1.shape[0], self.ds1.shape[1]), res.shape)
+        self.assertTupleEqual((self.ds3.shape[0], self.ds3.shape[1]+self.ds4.shape[1]), res2.shape)
